import React, { lazy, Suspense } from 'react';
import { Mail, Phone, ArrowDown, Factory, Users, Settings, Globe } from 'lucide-react';
import Navbar from '../components/Navbar';
import OptimizedImage from '../components/OptimizedImage';

// Lazy load below-the-fold components
const ContactSection = lazy(() => import('../components/ContactSection'));
const Footer = lazy(() => import('../components/Footer'));

function Home() {
  const isDeployPreview = window.location.hostname.includes('deploy-preview');

  return (
    <div className="min-h-screen bg-white">
      {isDeployPreview && (
        <div className="fixed bottom-4 right-4 bg-blue-500 text-white rounded-full py-1 px-3 text-xs shadow-lg z-50 flex items-center">
          <span className="mr-1">🔍</span>
          Preview
        </div>
      )}
      <Navbar />

     {/* Hero Section */}
     <section className="relative h-screen">
        {/* Pre-render the text content before the image loads */}
        <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 h-full flex items-center">
          <div className="text-white">
            <h1 className="font-sans font-bold text-4xl md:text-6xl leading-tight">
              Optimizing Textile Solutions
            </h1>
            <p className="mt-4 text-xl md:text-2xl text-white/90">
              Bringing 40 years of expertise to your textile challenges
            </p>
            <a
              href="#expertise"
              className="mt-8 inline-flex items-center px-6 py-3 border border-transparent font-roboto font-medium text-base rounded-md text-white bg-brand-primary hover:bg-brand-primary-dark"
            >
              Discover More
              <ArrowDown className="ml-2 h-5 w-5" />
            </a>
          </div>
        </div>

        {/* Background image */}
        <div className="absolute inset-0">
          <OptimizedImage
            src="/images/header"
            alt="Modern textile factory"
            className="w-full h-full object-cover"
            priority={true}
          />
          <div className="absolute inset-0 bg-black/50"></div>
        </div>
      </section>

        {/* Expertise Section */}
    <section id="expertise" className="py-20">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <h2 className="font-sans font-bold text-4xl mb-8">
            EXPERTISE IN<br />
            TEXTILE SOLUTIONS
          </h2>
          <p className="text-xl text-gray-600 mb-16 max-w-3xl">
            With over 40 years of experience in the textile industry, I help businesses optimize their textile 
            operations and develop sustainable solutions. My expertise spans from production optimization to 
            strategic sourcing.
          </p>

          <div className="grid md:grid-cols-3 gap-8">
            {/* Strategic Consulting */}
            <div className="bg-white rounded-lg overflow-hidden shadow-lg">
              <img
                src="/images/consulting-medium.jpg"
                alt="Strategic consulting"
                className="w-full h-64 object-cover"
              />
              <div className="p-8">
                <h3 className="font-sans font-bold text-2xl mb-6">Strategic Consulting</h3>
                <ul className="space-y-4 mb-6">
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Process Optimization
                  </li>
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Production Efficiency
                  </li>
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Quality Management
                  </li>
                </ul>
                <a href="/services#consulting" className="text-sm text-brand-primary hover:text-brand-primary-dark font-medium inline-flex items-center">
                  Learn more <ArrowDown className="ml-1 h-4 w-4 rotate-[-90deg]" />
                </a>
              </div>
            </div>

            {/* Global Network */}
            <div className="bg-white rounded-lg overflow-hidden shadow-lg">
              <img
                src="/images/network-medium.jpg"
                alt="Global network"
                className="w-full h-64 object-cover"
              />
              <div className="p-8">
                <h3 className="font-sans font-bold text-2xl mb-6">Network Access</h3>
                <ul className="space-y-4 mb-6">
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Supplier Connections
                  </li>
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Strategic Partnerships
                  </li>
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Market Access
                  </li>
                </ul>
                <a href="/services#network" className="text-sm text-brand-primary hover:text-brand-primary-dark font-medium inline-flex items-center">
                  Learn more <ArrowDown className="ml-1 h-4 w-4 rotate-[-90deg]" />
                </a>
              </div>
            </div>

            {/* Sustainability */}
            <div className="bg-white rounded-lg overflow-hidden shadow-lg">
              <img
                src="/images/sustainability-medium.jpg"
                alt="Sustainable solutions"
                className="w-full h-64 object-cover"
              />
              <div className="p-8">
                <h3 className="font-sans font-bold text-2xl mb-6">Sustainability</h3>
                <ul className="space-y-4 mb-6">
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Circular Solutions
                  </li>
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Eco-friendly Processes
                  </li>
                  <li className="flex items-center text-gray-600">
                    <span className="text-brand-primary mr-3">✓</span>
                    Waste Reduction
                  </li>
                </ul>
                <a href="/services#sustainability" className="text-sm text-brand-primary hover:text-brand-primary-dark font-medium inline-flex items-center">
                  Learn more <ArrowDown className="ml-1 h-4 w-4 rotate-[-90deg]" />
                </a>
              </div>
            </div>
          </div>
        </div>
      </section>
      

      {/* Global Network Section */}
      <section className="py-20 bg-brand-primary">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid md:grid-cols-2 gap-16">
            <div className="text-white">
              <h2 className="font-sans font-bold text-4xl mb-8">
                GLOBAL AND<br />
                CONNECTED
              </h2>
              <p className="text-xl mb-8">
                Building bridges across continents. From European craftsmanship to Asian innovation, 
                creating a network that delivers excellence in textile solutions.
              </p>
              <a 
                href="#contact" 
                className="inline-flex items-center px-8 py-3 bg-white text-brand-primary rounded-md font-medium hover:bg-gray-100 transition-colors"
              >
                Let's connect
                <ArrowDown className="ml-2 h-5 w-5" />
              </a>
            </div>

            <div className="space-y-6 text-white/90">
              <div className="flex items-start">
                <Globe className="h-6 w-6 mr-4 flex-shrink-0 mt-1" />
                <div>
                  <h3 className="font-semibold text-lg mb-2">European Excellence</h3>
                  <p>Strategic partnerships in Portugal, Spain, Poland, and Romania, combining traditional expertise with modern innovation.</p>
                </div>
              </div>

              <div className="flex items-start">
                <Factory className="h-6 w-6 mr-4 flex-shrink-0 mt-1" />
                <div>
                  <h3 className="font-semibold text-lg mb-2">Production Power</h3>
                  <p>Dedicated manufacturing facilities in Turkey and Pakistan, delivering quality and efficiency at scale.</p>
                </div>
              </div>

              <div className="flex items-start">
                <Settings className="h-6 w-6 mr-4 flex-shrink-0 mt-1" />
                <div>
                  <h3 className="font-semibold text-lg mb-2">Quality Control</h3>
                  <p>Experienced sourcing and quality management teams in China ensuring consistent standards across all productions.</p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Recent Developments Section */}
      <section className="py-20 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid md:grid-cols-2 gap-16">
            {/* Left content */}
            <div className="text-left">
              <h2 className="font-sans font-bold text-4xl mb-8">
                RECENT<br />
                DEVELOPMENTS
              </h2>
              <p className="text-xl text-gray-600 mb-12">
                Taking new steps toward making textile production better and more sustainable, with exciting developments in both technology and partnerships.
              </p>

              <div className="space-y-12">
                <div className="flex items-start">
                  <div className="flex-shrink-0 w-12 h-12 bg-brand-primary rounded-lg flex items-center justify-center mr-6">
                    <Factory className="h-6 w-6 text-white" />
                  </div>
                  <div>
                    <h3 className="font-sans font-semibold text-xl mb-3">New Production Facility</h3>
                    <p className="text-gray-600">
                      I've established a new production facility that combines modern technology with eco-friendly practices, 
                      allowing me to better serve my clients while respecting the environment.
                    </p>
                  </div>
                </div>

                <div className="flex items-start">
                  <div className="flex-shrink-0 w-12 h-12 bg-brand-primary rounded-lg flex items-center justify-center mr-6">
                    <Users className="h-6 w-6 text-white" />
                  </div>
                  <div>
                    <h3 className="font-sans font-semibold text-xl mb-3">Specialized Workwear</h3>
                    <p className="text-gray-600">
                      Working with an experienced team in Pakistan, I'm now able to offer specialized workwear solutions 
                      that combine comfort, durability, and practicality.
                    </p>
                  </div>
                </div>
              </div>
            </div>

            {/* Right image column with overlay - hidden on mobile, visible from md breakpoint up */}
            <div className="relative h-full hidden md:block">
              <div className="h-[600px] rounded-lg overflow-hidden">
                <img
                  src="/images/developments-medium.jpg"
                  alt="Modern textile production facility"
                  className="w-full h-full object-cover"
                />
                {/* Semi-transparent gradient overlay */}
                <div className="absolute inset-0 bg-gradient-to-t from-black/30 to-transparent" />
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Stats/Achievement Section */}
      <section className="py-16 bg-brand-primary relative overflow-hidden">
        <div className="absolute inset-0 opacity-10">
          <svg className="w-full h-full" viewBox="0 0 100 100" preserveAspectRatio="none">
            <pattern id="grid" width="10" height="10" patternUnits="userSpaceOnUse">
              <path d="M 10 0 L 0 0 0 10" fill="none" stroke="currentColor" strokeWidth="0.5"/>
            </pattern>
            <rect width="100" height="100" fill="url(#grid)"/>
          </svg>
        </div>
        
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative">
          <div className="grid md:grid-cols-4 gap-8 text-white">
            <div className="text-center">
              <div className="font-bold text-5xl mb-2">40+</div>
              <div className="text-white/80">Years Experience</div>
            </div>
            <div className="text-center">
              <div className="font-bold text-5xl mb-2">12</div>
              <div className="text-white/80">Countries</div>
            </div>
            <div className="text-center">
              <div className="font-bold text-5xl mb-2">50+</div>
              <div className="text-white/80">Partner Brands</div>
            </div>
            <div className="text-center">
              <div className="font-bold text-5xl mb-2">100%</div>
              <div className="text-white/80">Commitment</div>
            </div>
          </div>
        </div>
      </section>

      {/* Wrap below-the-fold sections in Suspense */}
      <Suspense fallback={<div className="h-20" />}>
        <ContactSection formName="home-contact" bgColor="bg-gray-50" />
        <Footer />
      </Suspense>
    </div>
  );
}

export default Home; 